#
# spec file for package ghc-persistent
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name persistent
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.13.3.0
Release:        bp154.1.19
Summary:        Type-safe, multi-backend data serialization
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-attoparsec-devel
BuildRequires:  ghc-base64-bytestring-devel
BuildRequires:  ghc-blaze-html-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-conduit-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-fast-logger-devel
BuildRequires:  ghc-http-api-data-devel
BuildRequires:  ghc-lift-type-devel
BuildRequires:  ghc-monad-logger-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-path-pieces-devel
BuildRequires:  ghc-resource-pool-devel
BuildRequires:  ghc-resourcet-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-scientific-devel
BuildRequires:  ghc-silently-devel
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-th-lift-instances-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unliftio-core-devel
BuildRequires:  ghc-unliftio-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-vault-devel
BuildRequires:  ghc-vector-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-quickcheck-instances-devel
BuildRequires:  ghc-shakespeare-devel
%endif

%description
Hackage documentation generation is not reliable. For up to date documentation,
please see: <http://www.stackage.org/package/persistent>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%changelog
* Sat Jan 29 2022 Peter Simons <psimons@suse.com>
- Update persistent to version 2.13.3.0.
  [#]# 2.13.3.0
  * [#1341](https://github.com/yesodweb/persistent/pull/1341)
  * Add `SqlBackendHooks` to allow for instrumentation of queries.
  * [#1327](https://github.com/yesodweb/persistent/pull/1327)
  * Update `SqlBackend` to use new `StatementCache` interface
    instead of `IORef (Map Text Statement)`
  [#]# 2.13.2.2
  * [#1351](https://github.com/yesodweb/persistent/pull/1351/)
  * `aeson-2.0` support
* Tue Oct 19 2021 psimons@suse.com
- Update persistent to version 2.13.2.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Oct 14 2021 psimons@suse.com
- Update persistent to version 2.13.2.1.
  [#]# 2.13.2.1
  * [#1329](https://github.com/yesodweb/persistent/pull/1329)
  * Prevent discovery of constrained `PersistEntity` instances in
    `discoverEntities` (since the discovered instances won't work without
    constraints anyway).
  [#]# 2.13.2.0
  * [#1314](https://github.com/yesodweb/persistent/pull/1314)
  * Fix typos and minor documentation issues in Database.Persist and
    Database.Persist.Quasi.
  * [#1317](https://github.com/yesodweb/persistent/pull/1317)
  * Expose `orderClause` from the Persistent internals, which allows users
    to produce well-formatted `ORDER BY` clauses.
  * [#1319](https://github.com/yesodweb/persistent/pull/1319)
  * Add a `Num` instance for `OverflowNatural`
* Tue Oct 12 2021 psimons@suse.com
- Update persistent to version 2.13.1.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Sep  3 2021 psimons@suse.com
- Update persistent to version 2.13.1.2.
  [#]# 2.13.1.2
  * [#1308](https://github.com/yesodweb/persistent/pull/1308)
  * Consolidate the documentation for the Persistent quasiquoter in
    Database.Persist.Quasi.
  * [#1312](https://github.com/yesodweb/persistent/pull/1312)
  * Reorganize documentation and link to more modules.
  * Expose `Database.Persist.Sql.Migration`
* Thu Jul  1 2021 psimons@suse.com
- Update persistent to version 2.13.1.1.
  [#]# 2.13.1.1
  * [#1294](https://github.com/yesodweb/persistent/pull/1294)
  * Fix an issue where documentation comments on fields are in reverse line
    order.
  [#]# 2.13.1.0
  * [#1264](https://github.com/yesodweb/persistent/pull/1264)
  * Support declaring Maybe before the type in model definitions
* Thu Jun 24 2021 psimons@suse.com
- Update persistent to version 2.13.0.4.
  [#]# 2.13.0.4
  * [#1277](https://github.com/yesodweb/persistent/pull/1277)
  * Corrected the documentation of `addMigration` to match the actual
    behaviour - this will not change the behaviour of your code.
* Sat Jun 19 2021 psimons@suse.com
- Update persistent to version 2.13.0.3.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/persistent-2.13.0.3/src/ChangeLog.md
* Wed May 26 2021 psimons@suse.com
- Update persistent to version 2.13.0.2.
  [#]# 2.13.0.2
  * [#1265](https://github.com/yesodweb/persistent/pull/1265)
  * Support GHC 9
* Tue May 11 2021 psimons@suse.com
- Update persistent to version 2.13.0.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/persistent-2.13.0.1/src/ChangeLog.md
* Sat May  8 2021 psimons@suse.com
- Update persistent to version 2.13.0.0 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri May  7 2021 psimons@suse.com
- Update persistent to version 2.13.0.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu May  6 2021 psimons@suse.com
- Update persistent to version 2.13.0.0.
  [#]# 2.13.0.0
  * [#1244](https://github.com/yesodweb/persistent/pull/1244)
  * Implement config for customising the FK name
  * [#1252](https://github.com/yesodweb/persistent/pull/1252)
  * `mkMigrate` now defers to `mkEntityDefList` and `migrateModels` instead of
    fixing the foreign key references itself.
  * `mkSave` was deprecated - the function did not fix foreign key references.
    Please use `mkEntityDefList` instead.
  * `EntityDef` will now include fields marked `MigrationOnly` and
    `SafeToRemove`. Beforehand, those were filtered out, and `mkMigrate`
    applied. The function `getEntityFields` wll only return fields defined on
    the Haskell type - for all columns, see `getEntityFieldsDatabase`.
  * [#1225](https://github.com/yesodweb/persistent/pull/1225)
  * The fields and constructor for `SqlBackend` are no longer exported by
    default. They are available from an internal module,
    `Database.Persist.Sql.Types.Internal`. Breaking changes from `Internal`
    modules are not reflected in the major version. This will allow us to
    release new functionality without breaking your code. It's recommended to
    switch to using the smart constructor functions and setter functions that
    are now exported from `Database.Persist.Sql` instead.
  * A new API is available for constructing and using a `SqlBackend`, provided
    in `Database.Persist.SqlBackend`. Instead of using the `SqlBackend`
    directly, use `mkSqlBackend` and the datatype `MkSqlBackendArgs`. The
    `MkSqlBackendArgs` record has the same field names as the `SqlBackend`, so
    the translation is easy:
    ```diff
  - SqlBackend
  + mkSqlBackend MkSqlBackendArgs
    { connInsertSql = ...
    , connCommit = ...
    , connEscapeFieldName = ...
    , connEscapeTableName = ...
    , etc
    }
    ```
    Some fields were omitted in `MkSqlBackendArgs`. These fields are
  * optional* - they provide enhanced or backend-specific functionality. For
    these, use the setter functions like `setConnUpsertSql`.
  * Previously hidden modules are now exposed under the `Internal` namespace.
  * The `connLimitOffset` function used to have a `Bool` parameter. This
    parameter is unused and has been removed.
  * [#1234](https://github.com/yesodweb/persistent/pull/1234)
  * You can now customize the default implied ID column. See the documentation
    in `Database.Persist.ImplicitIdDef` for more details.
  * Moved the various `Name` types into `Database.Persist.Names`
  * Removed the `hasCompositeKey` function. See `hasCompositePrimaryKey` and
    `hasNaturalKey` as replacements.
  * The `EntityDef` constructor and field labels are not exported by default.
    Get those from `Database.Persist.EntityDef.Internal`, but you should
    migrate to the getters/setters in `Database.Persist.EntityDef` as you can.
  * Added the `Database.Persist.FieldDef` and
    `Database.Persist.FieldDef.Internal` modules.
  * The `PersistSettings` type was made abstract. Please migrate to the
    getters/setters defined in that `Database.Persist.Quasi`, or use
    `Database.Persist.Quasi.Internal` if you don't mind the possibility of
    breaking changes.
  * Add the `runSqlCommand` function for running arbitrary SQL during
    migrations.
  * Add `migrateModels` function for a TH-free migration facility.
  * [#1253](https://github.com/yesodweb/persistent/pull/1253)
  * Add `discoverEntities` to discover instances of the class and return their
    entity definitions.
  * [#1250](https://github.com/yesodweb/persistent/pull/1250)
  * The `mpsGeneric` function has been deprecated. If you need this
    functionality, please comment with your needs on the GitHub issue tracker.
    We may un-deprecate it, or we may provide a new and better means of
    facilitating a solution to your problem.
  * [#1255](https://github.com/yesodweb/persistent/pull/1255)
  * `mkPersist` now checks to see if an instance already exists for
    `PersistEntity` for the inputs.
  [#]# 2.12.1.2
  * [#1258](https://github.com/yesodweb/persistent/pull/1258)
  * Support promoted types in Quasi Quoter
  * [#1243](https://github.com/yesodweb/persistent/pull/1243)
  * Assorted cleanup of TH module
  * [#1242](https://github.com/yesodweb/persistent/pull/1242)
  * Refactor setEmbedField to use do notation
  * [#1237](https://github.com/yesodweb/persistent/pull/1237)
  * Remove nonEmptyOrFail function from recent tests
  * [#1256](https://github.com/yesodweb/persistent/pull/1256)
  * The QuasiQuoter has been refactored and improved.
  * You can now use `mkPersistWith` to pass in a list of pre-existing
    `EntityDef` to improve foreign key detection and splitting up models
    across multiple modules.
  * The `entityId` field now returns an `EntityIdDef`, which specifies what
    the ID field actually is. This is a move to better support natural keys.
  * Several types that had lists have been refactored to use nonempty lists to
    better capture the semantics.
  * `mkDeleteCascade` is deprecated. Please use the Cascade behavior directly
    on fields.
  * You can use `Key Foo` and `FooId` interchangeably in fields.
  * Support for GHC < 8.4 dropped.
* Thu Apr 22 2021 psimons@suse.com
- Update persistent to version 2.12.1.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/persistent-2.12.1.1/src/ChangeLog.md
* Thu Apr  8 2021 psimons@suse.com
- Update persistent to version 2.12.1.0.
  [#]# 2.12.1.0
  * [#1226](https://github.com/yesodweb/persistent/pull/1226)
  * Expose the `filterClause` and `filterClauseWithValues` functions to support
    the `upsertWhere` functionality in `persistent-postgresql`.
* Mon Apr  5 2021 psimons@suse.com
- Update persistent to version 2.12.0.2.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/persistent-2.12.0.2/src/ChangeLog.md
* Thu Apr  1 2021 psimons@suse.com
- Update persistent to version 2.12.0.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Mar 30 2021 psimons@suse.com
- Update persistent to version 2.12.0.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/persistent-2.12.0.1/src/ChangeLog.md
* Fri Mar 19 2021 psimons@suse.com
- Update persistent to version 2.11.0.4.
  [#]# 2.11.0.4
  * Fix a compile error [#1213](https://github.com/yesodweb/persistent/pull/1213)
  * That's what I get for running this stuff with flakey CI!
* Thu Mar 18 2021 psimons@suse.com
- Update persistent to version 2.11.0.3.
  [#]# 2.11.0.3
  * Backported the fix from [#1207](https://github.com/yesodweb/persistent/pull/1207) for asynchronous exceptions.
  * Deprecated the `Acquire` family of functions.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Sat Dec 12 2020 psimons@suse.com
- Update persistent to version 2.11.0.2.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/persistent-2.11.0.2/src/ChangeLog.md
* Sat Nov  7 2020 psimons@suse.com
- Update persistent to version 2.11.0.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/persistent-2.11.0.1/src/ChangeLog.md
* Tue Nov  3 2020 psimons@suse.com
- Update persistent to version 2.10.5.3.
  [#]# 2.10.5.3
  * Backported the fix from [#1135](https://github.com/yesodweb/persistent/pull/1135) to the 2.10 branch.
    This should fix reading `PersistUTCTime` values.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jul 28 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints min 4GB disk space for few arches
  aarch64 ppc64 ppc64le
* Tue Jun  9 2020 psimons@suse.com
- Add persistent at version 2.10.5.2.
